@@ -9,13 +9,14 @@
 #' @aliases ploth
 #' @title Plot histograms for a data.frame
 #' @description Plotting histograms for a data.frame. Also the function will name the graphs and number the graphs.
-#' @usage ploth(x,c)
+#' @usage ploth(x,c,l)
 #' @param x :a dataframe
 #' @param c :is there dummy variable in the data.frame; c = 0 when there is none; c = 1 when there is
-#' @examples #ploth(sp500,0) for histograms of sp500 which does not has dummy variables
+#' @param l : number of labeling starts at (default = 1)
+#' @examples #ploth(sp500,0,20) for histograms of sp500 which does not has dummy variables
 
 
-ploth <- function(x,c){
+ploth <- function(x,c,l = 1){
   typeofvar <- sapply(x,class)
   ha <- typeofvar[typeofvar == "numeric"]
   if(c == 1){
@@ -29,6 +30,6 @@ ploth <- function(x,c){
   var <- names(x)
   n <- length(var)
     for(i in 1:n){
-      hist(x[,i], main = paste("Fig.", paste(i, paste("Histogram of",var[i]))), xlab = var[i])
+      hist(x[,i], main = paste("Fig.", paste(l+i-1, paste("Histogram of",var[i]))), xlab = var[i])
     }
 }
